@@ -329,7 +329,6 @@ public class MailsEndpoint {
 
     private Response setFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
-        log.info("Setting flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -429,7 +428,6 @@ public class MailsEndpoint {
 
     private Response clearFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
-        log.info("Clearing flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
