@@ -49,9 +49,6 @@
 
 package com.openexchange.mobile.api.facade.exceptions;
 
-import java.util.Collections;
-import java.util.List;
-
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.core.Response.Status;
@@ -84,14 +81,8 @@ public class ApiFacadeException extends WebApplicationException {
 
         int EMPTY_ARRAY_NOT_ALLOWED = 8;
 
-        int INVALID_ACCOUNT_DATA = 9;
-
         int REDIRECT = 10;
 
-        int SERVICE_UNAVAILABLE = 11;
-
-        int PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED = 12;
-
         String INVALID_SESSION = "SES-206";
 
         int CLIENT_UPDATE_MANDATORY = 900;
@@ -117,26 +108,10 @@ public class ApiFacadeException extends WebApplicationException {
             return invalidSession();
         } else if (areCredentialsInvalid(code)) {
             return invalidCredentials();
-        } else if (isDatabaseUpdate(code)) {
-            return serviceUnavailable();
-        } else if (isPasswordOfSecondaryAccountChanged(code)) {
-            return passwordSecondaryAccountChanged();
         } else if (isRedirect(code)) {
             return redirect(error);
         }
-        List<String> categories = getCategories(responseBody.getCategories());
-        return create(Status.BAD_REQUEST, code, null, responseBody.getErrorDescription(), categories);
-    }
-
-    @SuppressWarnings("unchecked")
-    private static List<String> getCategories(Object categories) {
-        if (categories instanceof String) {
-            return Collections.<String>singletonList((String) categories);
-        } else if (categories instanceof List) {
-            return (List<String>) categories;
-        } else {
-            return null;
-        }
+        return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
     }
 
     private static boolean isMaximumNumberOfSessionsExceeded(String code) {
@@ -152,14 +127,6 @@ public class ApiFacadeException extends WebApplicationException {
         return "MSG-1000".equals(code) || "LGI-0006".equals(code);
     }
 
-    private static boolean isDatabaseUpdate(String code) {
-        return "CTX-0007".equals(code);
-    }
-
-    private static boolean isPasswordOfSecondaryAccountChanged(String code) {
-        return "MSG-1016".equals(code);
-    }
-
     private static boolean isRedirect(String code) {
         return "LGI-0016".equals(code);
     }
@@ -233,15 +200,15 @@ public class ApiFacadeException extends WebApplicationException {
     }
 
     private static ApiFacadeException create(Status status, int errorCode, Exception cause, String message) {
-        return create(status, String.valueOf(errorCode), cause, message, null);
+        return create(status, String.valueOf(errorCode), cause, message);
     }
 
     private static ApiFacadeException create(Status status, String errorCode, String message) {
-        return create(status, errorCode, null, message, null);
+        return create(status, errorCode, null, message);
     }
 
-    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message, List<String> categories) {
-        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message, categories));
+    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message) {
+        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message));
         Response response = Response.status(status).entity(responseBody).build();
         return new ApiFacadeException(errorCode, cause, message, response);
     }
@@ -254,16 +221,4 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.NOT_FOUND, Code.ACCOUNT_NOT_FOUND, "Account not found: " + accountId);
     }
 
-    public static ApiFacadeException invalidAccountData() {
-        return create(Status.BAD_REQUEST, Code.INVALID_ACCOUNT_DATA, "Invalid account data");
-    }
-
-    public static ApiFacadeException serviceUnavailable() {
-        return create(Status.SERVICE_UNAVAILABLE, Code.SERVICE_UNAVAILABLE, "Service unavailable");
-    }
-
-    public static ApiFacadeException passwordSecondaryAccountChanged() {
-        return create(Status.SERVICE_UNAVAILABLE, Code.PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED, "Password of secondary mail account changed");
-    }
-
 }
