@@ -56,10 +56,10 @@ import com.openexchange.config.Reloadables;
 import com.openexchange.mobile.api.facade.auth.AuthenticationService;
 import com.openexchange.mobile.api.facade.auth.impl.DefaultAuthenticationService;
 import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
+import com.openexchange.mobile.api.facade.configuration.GlobalConfiguration;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.connectors.impl.DefaultConnectorFactoryFactory;
 import com.openexchange.mobile.api.facade.endpoints.AccountsEndpoint;
-import com.openexchange.mobile.api.facade.endpoints.AccountsEndpointV2;
 import com.openexchange.mobile.api.facade.endpoints.AuthenticationEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ConfigEndpoint;
 import com.openexchange.mobile.api.facade.endpoints.ContactsEndpoint;
@@ -107,7 +107,9 @@ public class Activator extends HousekeepingActivator implements Reloadable {
             ConfigurationService configurationService = getService(ConfigurationService.class);
             ConfigurationHelper.initialize(configurationService);
             ConnectorFactoryFactory connectorFactoryFactory = new DefaultConnectorFactoryFactory();
-            VersionCheckerUtil.check(connectorFactoryFactory);
+            if (GlobalConfiguration.versionCheckEnabled) {
+                VersionCheckerUtil.check(connectorFactoryFactory);
+            }
             registerServices(connectorFactoryFactory);
         } catch (Exception e) {
             log.error("failed to initialize bundle: \"com.openexchange.mobile.api.facade\": " + e.getMessage());
@@ -138,7 +140,6 @@ public class Activator extends HousekeepingActivator implements Reloadable {
         AccountsService accountsService = new AccountsService(connectorFactoryFactory, foldersService);
         foldersService.setAccountsService(accountsService);
         registerService(AccountsEndpoint.class, new AccountsEndpoint(accountsService));
-        registerService(AccountsEndpointV2.class, new AccountsEndpointV2(accountsService));
 
         MailsService mailsService = new MailsService(connectorFactoryFactory);
         registerService(MailsEndpoint.class, new MailsEndpoint(mailsService));
