@@ -63,10 +63,8 @@ import com.openexchange.mobile.api.facade.models.MailContact;
 import com.openexchange.mobile.api.facade.models.MailThread;
 
 import lombok.experimental.UtilityClass;
-import lombok.extern.slf4j.Slf4j;
 
 @UtilityClass
-@Slf4j
 public class MailUtil {
 
     private final MapFunction<ThreadReferenceMto, MailThread> threadMapFunction = new MapFunction<ThreadReferenceMto, MailThread>() {
@@ -209,17 +207,4 @@ public class MailUtil {
         return cleanedThreads;
     }
 
-    public Long readAsLong(Object value) {
-        if (value instanceof Long) {
-            return (Long) value;
-        } else if (value instanceof Integer) {
-            return ((Integer) value).longValue();
-        } else if (value == null) {
-            return null;
-        } else {
-            log.error("Cannot read value as Long: " + value.toString());
-            return null;
-        }
-    }
-
 }
